## @file pointADT.py
#  @author Sepehr
#  @brief Provides the PointT ADT class for representing 2D points
#  @date 25 Jan 2018

from math import *

##@brief An ADT that respresents a 2D point
class PointT:

    ## @brief PointT constructor
    #  @details Initializes a PointT object with a cartesian coordinate
    #  @param x The x coordinate of the point
    #  @param y The y coordinate of the point
    def __init__(self, x, y):
        self.__xc = x
        self.__yc = y

    ## @brief Gets the x coordinate of the point
    #  @return The x coordinate of the point
    def xcoord(self):
        return self.__xc

    ## @brief Gets the y coordinate of the point
    #  @return The y coordinate of the point
    def ycoord(self):
        return self.__yc

     ## @brief Determines the distance between 2 points
     #  @details Uses pythagorean theorem
     #  @param p Another point
     #  @return The distance between the given points
    def dist(self, p):
        xDist = self.__xc - p.xcoord()
        yDist = self.__yc - p.ycoord()
        return sqrt(xDist ** 2 + yDist ** 2)
